@@ -3,7 +3,7 @@ package Tree::Simple::Visitor;
 use strict;
 use warnings;
 
-our $VERSION = '1.32';
+our $VERSION = '1.34';
 
 use Scalar::Util qw(blessed);
 
@@ -288,6 +288,10 @@ B<Tree::Simple>) and is based on an (non-publicly released) module which I had u
 systems for about 2 years without incident. Of course, if you find a bug, let me know, and I will
 be sure to fix it.
 
+Bugs should be reported via the CPAN bug tracker at
+
+L<https://github.com/ronsavage/Tree-Simple/issues>
+
 =head1 SEE ALSO
 
 I have written a set of pre-built Visitor objects, available on CPAN as
